@@ -3,4 +3,8 @@ import click
 FRUITCONFIG_NAME = "fruitconfig.py"
 
 FMT_STEPHEADER = "🥝 Step {number}: {name}\n" + "-"* (click.get_terminal_size()[0] - 5)
-SHELLCHAR = '$ '
\ No newline at end of file
+SHELLCHAR = '$ '
+
+ICON_SUCC = "✅"
+ICON_FAIL    = "❌"
+ICON_SKIP    = "⏭"
\ No newline at end of file
